@@ -5,7 +5,7 @@ use Socket;
 use IO::Socket::INET;
 use Scalar::Util 'reftype';
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
  
 $| = 1;
 
@@ -45,7 +45,7 @@ sub resolveReq {
     if ($what !~ /\\d+\\.\\d+\\.\\d+\\.\\d+/) {
         my @host = gethostbyname($what);
         if (scalar(@host) == 0) {
-            die "Failed host to resolve to IP: $what\n";
+            return;
         } else {
             return Socket::inet_ntoa($host[4]);
         }
@@ -59,11 +59,25 @@ sub pwhois {
     my $what = shift;
 
     my @req;
-    if (Scalar::Util::reftype($what) eq 'ARRAY') {
-        @req  = @{$what};
+
+    # Here for legacy purposes only.
+    if ($self->{req}) { 
+        @req  = @{$self->{req}};
     }
-    else {
-        push @req, $what;
+
+    # Passed value shall trump legacy.
+    if ($what) {
+        if (Scalar::Util::reftype($what) eq 'ARRAY') {
+            @req  = @{$what};
+        }
+        else {
+            push @req, $what;
+        }
+    }
+
+    if (! @req) {
+        # Nothing to process.
+        return;
     }
 
     my $socket = new IO::Socket::INET (
@@ -74,10 +88,15 @@ sub pwhois {
     die "Cannot connect to server $!\n" unless $socket;
 
     # Build request
+    # This array is needed to handle hosts which can't be resolved to IP.
+    my @req_new;
     my $request = "begin\n";
     for my $elmt (@req) {
         my $resolved = $self->resolveReq($elmt);
-        $request .= "$resolved\n";
+        if ($resolved) {
+            $request .= "$resolved\n";
+	    push @req_new, $elmt;
+        }
     }
     $request .= "end\n";
 
@@ -94,7 +113,7 @@ sub pwhois {
     my $cntr = 0;
     for my $response (split /\n\n/, $responses) {
         my $formatted = $self->formatResponse($response);
-        $results{$req[$cntr++]} = $formatted;
+        $results{$req_new[$cntr++]} = $formatted;
     }
 
     return \%results;
@@ -128,7 +147,7 @@ sub printReport {
     my $report;
     for my $req (keys %{$what}) {
         $report .= sprintf ("Request: %s\n", $req);
-        for my $key (keys %{$what->{$req}}) {
+        for my $key (sort keys %{$what->{$req}}) {
             $report .= sprintf("%-22s : %s\n", $key, $what->{$req}{$key});
         }
     }
@@ -153,6 +172,7 @@ Net::pWhoIs - Client library for Prefix WhoIs (pWhois)
         207.20.243.105
         67.225.131.208
         perlmonks.org
+	brokenhost.brokendomain.co
         8.8.8.8
         12.12.12.12
         ftp2.freebsd.org
@@ -161,7 +181,7 @@ Net::pWhoIs - Client library for Prefix WhoIs (pWhois)
     # You can pass an array.
     my $output = $obj->pwhois(\@array);
 
-    # Or you can pass a single string.
+    # Or you can pass a scalar.
     my $output = $obj->pwhois('8.8.8.8');
 
     # Generate a formatted report.
@@ -188,11 +208,10 @@ Client library for pWhois service.  Includes support for bulk queries.
 
 Construct a new C<Net::pWhoIs> object and return it.
 Key/value pair arguments may be provided to set up the initial state.
-The only require argument is: req.
+The 
 
     pwhoisserver  whois.pwhois.org
     port          43
-    req           Required argument, value must be an array reference.
 
 =back
 
@@ -204,7 +223,7 @@ The following methods are available:
 
 =item Net::pWhoIs->pwhois()
 
-Perform queries on passed arrayref.  Supports single or bulk query.  Returns a hash of hashrefs.
+Perform queries on passed arrayref or scalar.  Thus both single query and bulk queries supported.  Returns a hash of hashrefs.  Unresolvable hostnames are skipped.
 
 =back
 
@@ -212,7 +231,7 @@ Perform queries on passed arrayref.  Supports single or bulk query.  Returns a h
 
 =item Net::pWhoIs->printReport()
 
-Perform queries on passed arrayref.  Supports single or bulk query.  Returns a hash of hashrefs.
+An optional method which generates a formated report to stdout.  Accepts returned output from Net::pWhoIs->pwhois()
 
 =back
 
